
TODO_75_52_01_67: `arg_bucket`-s to support multiple var args

Because FS_97_64_39_94 `arg_bucket`-s limit consumption per `envelope_container`,
it is possible to support more than one FS_18_64_57_18 varargs - each `arg_bucket` specifying its own list.

TODO: This will require update to logic how to move current `envelope_container`
      to next one based on location of cursor in relation to `arg_bucket` delimiters.
